==> haskell-microstache-1.0.1.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-4xTSk7y7zsMEmtI5S54r1
key: microstache-1.0.1.1-4xTSk7y7zsMEmtI5S54r1
license: BSD3
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
abi: 4214c3ddca172ba450874015704a202b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-4xTSk7y7zsMEmtI5S54r1
depends:
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn base-4.10.0.0
    bytestring-0.10.8.2 containers-0.5.10.2 deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh transformers-0.5.2.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=002a869bdbfad797ec5fba636ef9d0d8
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.1.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-e8D45RrR4564f2dxS5nG5
key: microstache-1.0.1.1-e8D45RrR4564f2dxS5nG5
license: BSD3
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
abi: 5e8902721bcdd399a42e76fb4cc7af38
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-e8D45RrR4564f2dxS5nG5
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0
    bytestring-0.10.8.2 containers-0.5.10.2 deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh transformers-0.5.2.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
